"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var axios_1 = __importDefault(require("axios"));
function createBaseClient(client) {
    if (client === void 0) { client = axios_1.default; }
    var baseHeaders = { "Content-Type": "application/json" };
    function createConfig(config) {
        return __assign({}, config, { headers: __assign({}, baseHeaders, (!!config ? config.headers : {})) });
    }
    return {
        get: function (url, config) {
            return client.get(url, createConfig(config)).then(function (_a) {
                var data = _a.data;
                return data;
            });
        },
        post: function (url, body, config) {
            return client.post(url, body, createConfig(config)).then(function (_a) {
                var data = _a.data;
                return data;
            });
        },
        patch: function (url, body, config) {
            return client.patch(url, body, createConfig(config)).then(function (_a) {
                var data = _a.data;
                return data;
            });
        },
        delete: function (url, body, config) {
            return client
                .delete(url, createConfig(__assign({}, config, { data: body })))
                .then(function (_a) {
                var data = _a.data;
                return data;
            });
        },
        head: function (url, config) { return client.head(url, createConfig(config)); }
    };
}
exports.createBaseClient = createBaseClient;
/**
 * Treat client and server as if originating from the same domain, and whatever
 * URL the client is at, the server has the corresponding URL that contains the
 * data. This is assuming there is a subdomain called "api" for the server at
 * the same domain.
 *
 * e.g.
 * client -> https://localhost:8000/users/
 * server -> https://api.localhost:8000/users/1
 */
function createRelativeClient(_a, client) {
    var location = _a.location;
    function getFullURL(url) {
        var origin = location.origin;
        return origin + "/api" + url;
    }
    return {
        get: function (url, config) { return client.get(getFullURL(url), config); },
        post: function (url, body, config) { return client.post(getFullURL(url), body, config); },
        patch: function (url, body, config) { return client.patch(getFullURL(url), body, config); },
        delete: function (url, body, config) { return client.delete(getFullURL(url), body, config); },
        head: function (url, config) { return client.head(getFullURL(url), config); }
    };
}
exports.createRelativeClient = createRelativeClient;
